import { Component, OnInit, ViewChild } from "@angular/core";
import { NgbModal } from "@ng-bootstrap/ng-bootstrap";
import { NgBlockUI, BlockUI } from "ng-block-ui";
import {
  PerfectScrollbarDirective,
  PerfectScrollbarComponent,
  PerfectScrollbarConfigInterface,
} from "ngx-perfect-scrollbar";
import { TableApiService } from "src/app/_services/table-api.service";
import { ModalAddEditComponent } from "./modal-add-edit/modal-add-edit.component";

@Component({
  selector: "app-device",
  templateUrl: "./device.component.html",
  styleUrls: ["./device.component.css"],
})
export class DeviceComponent implements OnInit {
  data: any;

  @BlockUI("addRows") blockUIAddRows: NgBlockUI;
  @BlockUI("rowSelection") blockUIRowSelection: NgBlockUI;

  public config: PerfectScrollbarConfigInterface = { wheelPropagation: true };
  @ViewChild(PerfectScrollbarComponent)
  componentRef?: PerfectScrollbarComponent;
  @ViewChild(PerfectScrollbarDirective, { static: true })
  directiveRef?: PerfectScrollbarDirective;

  options = {
    close: true,
    expand: true,
    minimize: true,
    reload: true,
  };
  temp = [];
  selected = [];
  id: number;
  loadingIndicator: true;
  rows: any;
  editing = {};
  row: any;
  public breadcrumb: any;

  constructor(
    private tableApiservice: TableApiService,
    private modalService: NgbModal
  ) {}

  ngOnInit() {
    this.breadcrumb = {
      mainlabel: "Device List",
      links: [
        {
          name: "Home",
          isLink: false,
          link: "/dashboard/sales",
        },
        {
          name: "Device",
          isLink: false,
        },
      ],
    };
    this.tableApiservice.getTableApiData().subscribe((Response) => {
      console.log(Response);

      this.data = Response;
      this.getTabledata();
    });
  }

  getTabledata() {
    this.rows = this.data.rows;
    this.row = this.data.row;
  }

  private newAttribute = {
    id: 15,
    name: "Mark",
    position: "Otto",
    office: "@mdo",
    age: "31",
    salary: "12000",
    startdate: "16/05/2017",
  };

  // addFieldValue() {
  //   this.rows.push(this.newAttribute);
  //   this.rows = [...this.rows];
  // }

  addFieldValue() {
    const modalRef = this.modalService.open(ModalAddEditComponent, { size: 'lg' });
    modalRef.componentInstance.newAttribute = { id: null, name: '', position: '', office: '', age: '', salary: '', startdate: '' };
  
    modalRef.result.then((result) => {
      if (result) {
        this.rows.push(result);
        this.rows = [...this.rows];
      }
    }, (reason) => {
      console.log(`Dismissed: ${reason}`);
    });
  }
  
}
